#!/opt/local/bin/python 
# set matplotlib backend to PDF for fast off-screen plotting (this has to be done before loading pylab)
import matplotlib
matplotlib.use('ps')
#matplotlib.use('PDF')

# now load pylab and other modules
from pylab import *
import sys

# get command line arguments
meshDim = float(sys.argv[1])
divScheme = sys.argv[2]
mesh = sys.argv[3]

# contours
ua=mlab.load("surfaces/1/UA_plane.raw")
us=mlab.load("surfaces/1/U_plane.raw")
x=ua[:,0]
y=ua[:,1]
uA=ua[:,3]
vA=ua[:,4]
uS=us[:,3]
vS=us[:,4]
X=reshape(x,(meshDim,meshDim))
Y=reshape(y,(meshDim,meshDim))
UA=reshape(sqrt(uA**2+vA**2),(meshDim,meshDim))
US=reshape(sqrt(uS**2+vS**2),(meshDim,meshDim))
levels = arange(0, 1.05*max(UA.max(),US.max()), 0.01)

axis('scaled')
title("Analytical solution $(A)$ Velocity Magnitude")
xlim(-1.6,1.6)
ylim(-1.6,1.6)
contourf(X,Y,UA,levels)
colorbar(fraction=0.045)
savefig("UMagAnalytical"+divScheme+mesh+".eps",format='eps')
#savefig("UMagAnalytical"+divScheme+mesh+".pdf",dpi=(300),format='pdf')
clf()

axis('scaled')
title("Simulation $(S)$ Velocity Magnitude, div(phi,U)="+divScheme)
xlim(-1.6,1.6)
ylim(-1.6,1.6)
contourf(X,Y,US,levels)
colorbar(fraction=0.045)
savefig("UMagSimulation"+divScheme+mesh+".eps",format='eps')
#savefig("UMagSimulation"+divScheme+mesh+".pdf",dpi=(300),format='pdf')
clf()

axis('scaled')
title("\% Comparison error $(S-A)/A_{max}$, div(phi,U)="+divScheme)
CE=US-UA
xlim(-1.6,1.6)
ylim(-1.6,1.6)
contourf(X,Y,100*CE/UA.max(),20)
colorbar(fraction=0.045)
savefig("UMagError"+divScheme+mesh+".eps",format='eps')
#savefig("UMagError"+divScheme+mesh+".pdf",dpi=(300),format='pdf')
clf()

pa=mlab.load("surfaces/1/pA_plane.raw")
p=mlab.load("surfaces/1/p_plane.raw")
x=pa[:,0]
y=pa[:,1]
pA=pa[:,3]
pS=p[:,3]
X=reshape(x,(meshDim,meshDim))
Y=reshape(y,(meshDim,meshDim))
pA=reshape(pA,(meshDim,meshDim))
pS=reshape(pS,(meshDim,meshDim))

axis('scaled')
title("Analytical solution $(A)$ pressure")
xlim(-1.6,1.6)
ylim(-1.6,1.6)
contourf(X,Y,pA,20)
colorbar(fraction=0.045)
savefig("pAnalytical"+divScheme+mesh+".eps",format='eps')
#savefig("pAnalytical"+divScheme+mesh+".pdf",dpi=(300),format='pdf')
clf()

axis('scaled')
title("Simulation $(S)$ pressure, div(phi,U)="+divScheme)
xlim(-1.6,1.6)
ylim(-1.6,1.6)
contourf(X,Y,pS,20)
colorbar(fraction=0.045)
savefig("pSimulation"+divScheme+mesh+".eps",format='eps')
#savefig("pSimulation"+divScheme+mesh+".pdf",dpi=(300),format='pdf')
clf()

axis('scaled')
title("\% Comparison error $(S-A)/A_{max}$ for pressure, div(phi,U)="+divScheme)
CE=pS-pA
xlim(-1.6,1.6)
ylim(-1.6,1.6)
contourf(X,Y,100*CE/UA.max(),20)
colorbar(fraction=0.045)
savefig("pError"+divScheme+mesh+".eps",format='eps')
#savefig("pError"+divScheme+mesh+".pdf",dpi=(300),format='pdf')
clf()

